# Legit Indicators

![Publish Python 🐍 distributions 📦 to PyPI and TestPyPI](https://github.com/aticio/legitindicators/workflows/Publish%20Python%20%F0%9F%90%8D%20distributions%20%F0%9F%93%A6%20to%20PyPI%20and%20TestPyPI/badge.svg)

Collection of indicators that I used in my strategies.

## List of indicators: ##

* Simple Moving Average
* Exponential Moving Average
* Average True Range
* Smoothed ATR - Super Smoother applied Average True Range
* Rolled Moving Average
* Atrlimit - Average True Range implementation with a limit for using as a volatility indicator
* Smoothed Atrlimit - Smoothed Average True Range implementation with a limit for using as a volatility indicator
* Roofing Filter - Python implementation of the Roofing Filter indicator created by John Ehlers
* Super Smoother - Python implementation of the Super Smoother indicator created by John Ehlers
* SZLADX - A low lagging upgrade of ADX indicator.
* True Range
* Decycler - Python implementation of Simple Decycler indicator created by John Ehlers
* Decycler Oscillator - Python implementation of Decycler Oscillator created by John Ehlers
* High Pass Filter
* Damiani Volatmeter
* Voss - Python implementation of Voss indicator created by John Ehlers
* Hurst Coefficient
* Kaufman Efficiency Ratio
* Even Better Sine Wave - Python implementation of Even Better Sine Wave indicator created by John Ehlers
* Cube Transform - Python implementation of Cube Transform created by John Ehlers
* Simple Harmonic Oscillator
* Smoothed Simple Harmonic Oscillator - Super Smoother applied Simple Harmonic Oscillator
* Kaufman Adaptive Moving Average
* Linear Regression Curve
* Linear Regression Slope
* TrendFlex - Python implementation of TrendFlex indicator created by John Ehlers
* Custom TrendFlex - Python implementation of TrendFlex indicator with customizable super smoother length, created by John Ehlers
* Automatic Gain Control - Python implementation of Automatic Gain Control created by John Ehlers
* Smoothed SSL - Super Smoother Applied SSL indicator
* Bollinger Bands %B
* Volume Heat - A custom volume indicator
* Double Super Smoother - Two Super Smoother indicators for checking line crosses
* EMA Trailing - A trailing stop implementation using Exponantial Moving Average
* Momentum Normalized - Normalized Momentum Indicator; Cube Transform applied


## Installation

Run the following to install:

```python
pip install legitindicators
```
